@@ -6,7 +6,7 @@ use Carp();
 
 use Rose::DB::Object::Iterator;
 use Rose::DB::Object::QueryBuilder qw(build_select);
-use Rose::DB::Object::Constants qw(STATE_LOADING STATE_IN_DB);
+use Rose::DB::Object::Constants qw(PRIVATE_PREFIX STATE_LOADING STATE_IN_DB);
 
 # XXX: A value that is unlikely to exist in a primary key column value
 use constant PK_JOIN => "\0\2,\3\0";
@@ -70,6 +70,16 @@ sub handle_error
   return 1;
 }
 
+use constant MAP_RECORD_ATTR   => PRIVATE_PREFIX . '_map_record';
+use constant MAP_RECORD_METHOD => 'map_record';
+use constant DEFAULT_REL_KEY   => PRIVATE_PREFIX . '_default_rel_key';
+
+my $Map_Record_Method = sub 
+{
+  return $_[0]->{MAP_RECORD_ATTR()} = $_[1]  if(@_ > 1);
+  return shift->{MAP_RECORD_ATTR()};
+};
+
 sub object_class { }
 
 sub default_manager_method_types { qw(objects iterator count delete update) }
@@ -173,7 +183,7 @@ sub make_manager_methods
       if($type eq 'objects')
       {
         my $method_name = 
-          $have_full_name ? $name : "${target_class}::get_$name";
+          $have_full_name ? "${target_class}::$name" : "${target_class}::get_$name";
 
         foreach my $class ($target_class, $class_invocant)
         {
@@ -191,7 +201,7 @@ sub make_manager_methods
       elsif($type eq 'count')
       {
         my $method_name =
-          $have_full_name ? $name : "${target_class}::get_${name}_count";
+          $have_full_name ? "${target_class}::$name" : "${target_class}::get_${name}_count";
 
         foreach my $class ($target_class, $class_invocant)
         {
@@ -210,7 +220,7 @@ sub make_manager_methods
       elsif($type eq 'iterator')
       {
         my $method_name =
-          $have_full_name ? $name : "${target_class}::get_${name}_iterator";
+          $have_full_name ? "${target_class}::$name" : "${target_class}::get_${name}_iterator";
 
         foreach my $class ($target_class, $class_invocant)
         {
@@ -229,7 +239,7 @@ sub make_manager_methods
       elsif($type eq 'delete')
       {
         my $method_name = 
-          $have_full_name ? $name : "${target_class}::delete_$name";
+          $have_full_name ? "${target_class}::$name" : "${target_class}::delete_$name";
 
         foreach my $class ($target_class, $class_invocant)
         {
@@ -247,7 +257,7 @@ sub make_manager_methods
       elsif($type eq 'update')
       {
         my $method_name = 
-          $have_full_name ? $name : "${target_class}::update_$name";
+          $have_full_name ? "${target_class}::$name" : "${target_class}::update_$name";
 
         foreach my $class ($target_class, $class_invocant)
         {
@@ -285,20 +295,23 @@ sub get_objects
 
   $class->error(undef);
 
-  my $return_sql      = delete $args{'return_sql'};
-  my $return_iterator = delete $args{'return_iterator'};
-  my $object_class    = delete $args{'object_class'} or Carp::croak "Missing object class argument";
-  my $count_only      = delete $args{'count_only'};
-  my $require_objects = delete $args{'require_objects'};
-  my $with_objects    = !$count_only ? delete $args{'with_objects'} : undef;
-  my $skip_first      = delete $args{'skip_first'} || 0;
-  my $distinct        = delete $args{'distinct'};
-  my $fetch           = delete $args{'fetch_only'};
+  my $return_sql       = delete $args{'return_sql'};
+  my $return_iterator  = delete $args{'return_iterator'};
+  my $object_class     = delete $args{'object_class'} or Carp::croak "Missing object class argument";
+  my $count_only       = delete $args{'count_only'};
+  my $require_objects  = delete $args{'require_objects'};
+  my $with_objects     = !$count_only ? delete $args{'with_objects'} : undef;
+
+  my $skip_first       = delete $args{'skip_first'} || 0;
+  my $distinct         = delete $args{'distinct'};
+  my $fetch            = delete $args{'fetch_only'};
   
   my(%fetch, %rel_name);
 
-  my $db  = delete $args{'db'} || $object_class->init_db;
-  my $dbh = delete $args{'dbh'};
+  my $meta = $object_class->meta;
+
+  my $db   = delete $args{'db'} || $object_class->init_db;
+  my $dbh  = delete $args{'dbh'};
   my $dbh_retained = 0;
 
   unless($dbh)
@@ -313,6 +326,27 @@ sub get_objects
     $dbh_retained = 1;
   }
 
+  my $with_map_records;
+
+  if($with_map_records = delete $args{'with_map_records'})
+  {
+    unless(ref $with_map_records)
+    {
+      if($with_map_records =~ /^[A-Za-z]\w*$/)
+      {
+        $with_map_records = { DEFAULT_REL_KEY() => $with_map_records };
+      }
+      elsif($with_map_records)
+      {
+        $with_map_records = { DEFAULT_REL_KEY() => MAP_RECORD_METHOD };
+      }
+      else
+      {
+        $with_map_records = 0;
+      }
+    }
+  }
+
   my $outer_joins_only = ($with_objects && !$require_objects) ? 1 : 0;
 
   my($num_required_objects, %required_object, 
@@ -376,15 +410,13 @@ sub get_objects
     $subobject_args{'db'} = $db;
   }
 
-  my $meta = $object_class->meta;
-
   my($fields, $fields_string, $table);
 
   $args{'nonlazy'} = []  unless(exists $args{'nonlazy'});
   my $nonlazy = $args{'nonlazy'};
   my %nonlazy = (ref $nonlazy ? map { $_ => 1 } @$nonlazy : ());
 
-  my @tables     = ($meta->fq_table);
+  my @tables     = ($meta->fq_table($db));
   my @tables_sql = ($meta->fq_table_sql($db));
 
   my $use_lazy_columns = (!ref $nonlazy || $nonlazy{'self'}) ? 0 : $meta->has_lazy_columns;
@@ -408,7 +440,7 @@ sub get_objects
 
   my @table_names = ($meta->table);
 
-  my(@joins, @subobject_methods, $clauses);
+  my(@joins, @subobject_methods, @mapped_object_methods, $clauses);
 
   my $handle_dups = 0;
   my @has_dups;
@@ -594,7 +626,7 @@ sub get_objects
 
         $meta{$ft_class} = $ft_meta;
 
-        push(@tables, $ft_meta->fq_table);
+        push(@tables, $ft_meta->fq_table($db));
         push(@tables_sql, $ft_meta->fq_table_sql($db));
         push(@table_names, $rel_name{'t' . (scalar @tables)} = $rel->name);
         push(@classes, $ft_class);
@@ -723,14 +755,33 @@ sub get_objects
 
         $meta{$map_class} = $map_meta;
 
-        push(@tables, $map_meta->fq_table);
+        push(@tables, $map_meta->fq_table($db));
         push(@tables_sql, $map_meta->fq_table_sql($db));
         push(@table_names, $rel_name{'t' . (scalar @tables)} = $rel->name);
         push(@classes, $map_class);
 
-        $columns{$tables[-1]} = []; # Don't fetch map class columns
+        if($with_map_records)
+        {
+          my $use_lazy_columns = (!ref $nonlazy || $nonlazy{$name}) ? 0 : $map_meta->has_lazy_columns;
+
+          if($use_lazy_columns)
+          {
+            $columns{$tables[-1]} = $map_meta->nonlazy_columns;
+            $methods{$tables[-1]} = $map_meta->nonlazy_column_mutator_method_names;
+          }
+          else
+          {
+            $columns{$tables[-1]} = $map_meta->columns;   
+            $methods{$tables[-1]} = $map_meta->column_mutator_method_names;        
+          }
+        }
+        else
+        {
+          $columns{$tables[-1]} = []; # Don't fetch map class columns
+          $methods{$tables[-1]} = [];
+        }
+
         $classes{$tables[-1]} = $map_class;
-        $methods{$tables[-1]} = [];
 
         my $column_map = $rel->column_map;
 
@@ -738,6 +789,22 @@ sub get_objects
         # Increase once for map table.
         $i++;
 
+        my $method = $mapped_object_methods[$i - 1] = 
+          exists $with_map_records->{$name} ? $with_map_records->{$name} : 
+          $with_map_records->{DEFAULT_REL_KEY()};
+
+        if($method)
+        {
+          my $ft_class = $rel->foreign_class 
+            or Carp::confess "$class - Missing foreign class for '$name'";
+          
+          unless($ft_class->can($method))
+          {
+            no strict 'refs';
+            *{"${ft_class}::$method"} = $Map_Record_Method;
+          }
+        }
+
         # Add join condition(s)
         while(my($local_column, $foreign_column) = each(%$column_map))
         {
@@ -786,7 +853,7 @@ sub get_objects
         my $ft_columns = $foreign_rel->key_columns 
           or Carp::confess "$ft_class - Missing key columns for '$map_to'";
 
-        push(@tables, $ft_meta->fq_table);
+        push(@tables, $ft_meta->fq_table($db));
         push(@tables_sql, $ft_meta->fq_table_sql($db));
         push(@table_names, $rel_name{'t' . (scalar @tables)} = $rel->name);
         push(@classes, $ft_class);
@@ -1193,6 +1260,8 @@ sub get_objects
 
                   $object ||= $last_object or die "Missing object for primary key '$pk'";
 
+                  my $map_record;
+
                   foreach my $i (1 .. $num_subtables)
                   {
                     my $class  = $classes[$i];
@@ -1216,7 +1285,21 @@ sub get_objects
                     # per-object sub-objects list.
                     if($has_dups[$i])
                     {
-                      push(@{$sub_objects[$i]}, $subobject);
+                      if($mapped_object_methods[$i])
+                      {
+                        $map_record = $subobject;
+                      }
+                      else
+                      {
+                        if($map_record)
+                        {
+                          my $method = $mapped_object_methods[$i - 1] or next;
+                          $subobject->$method($map_record);
+                          $map_record = 0;
+                        }
+
+                        push(@{$sub_objects[$i]}, $subobject);
+                      }
                     }
                     else # Otherwise, just assign it
                     {
@@ -1494,6 +1577,8 @@ sub get_objects
 
           $object ||= $last_object or die "Missing object for primary key '$pk'";
 
+          my $map_record;
+
           foreach my $i (1 .. $num_subtables)
           {
             my $class  = $classes[$i];
@@ -1517,7 +1602,21 @@ sub get_objects
             # per-object sub-objects list.
             if($has_dups[$i])
             {
-              push(@{$sub_objects[$i]}, $subobject);
+              if($mapped_object_methods[$i])
+              {
+                $map_record = $subobject;
+              }
+              else
+              {
+                if($map_record)
+                {
+                  my $method = $mapped_object_methods[$i - 1] or next;
+                  $subobject->$method($map_record);
+                  $map_record = 0;
+                }
+
+                push(@{$sub_objects[$i]}, $subobject);
+              }
             }
             else # Otherwise, just assign it
             {
@@ -1666,7 +1765,9 @@ sub delete_objects
 
   my $object_class = $args{'object_class'} or Carp::croak "Missing object class argument";
 
-  my $db  = $args{'db'} || $object_class->init_db;
+  my $meta = $object_class->meta;
+
+  my $db  = delete $args{'db'} || $object_class->init_db;
   my $dbh = $args{'dbh'};
   my $dbh_retained = 0;
 
@@ -1688,7 +1789,7 @@ sub delete_objects
   unless(($args{'query'} && @{$args{'query'}}) || delete $args{'all'})
   {
     Carp::croak "$class - Refusing to delete all rows from the table '",
-                $object_class->meta->fq_table, "' without an explict ",
+                $meta->fq_table($db), "' without an explict ",
                 "'all => 1' parameter";
   }
 
@@ -1697,8 +1798,6 @@ sub delete_objects
     Carp::croak "Illegal use of the 'where' and 'all' parameters in the same call";
   }
 
-  my $meta = $object_class->meta;
-
   # Yes, I'm re-using get_objects() code like crazy, and often
   # in weird ways.  Shhhh, it's a secret.
 
@@ -1741,7 +1840,9 @@ sub update_objects
   my $object_class = $args{'object_class'} 
     or Carp::croak "Missing object class argument";
 
-  my $db  = $args{'db'} || $object_class->init_db;
+  my $meta = $object_class->meta;
+
+  my $db  = delete $args{'db'} || $object_class->init_db;
   my $dbh = $args{'dbh'};
   my $dbh_retained = 0;
 
@@ -1761,7 +1862,7 @@ sub update_objects
   unless(($args{'where'} && @{$args{'where'}}) || delete $args{'all'})
   {
     Carp::croak "$class - Refusing to update all rows in the table '",
-                $object_class->meta->fq_table_sql($db), "' without an explict ",
+                $meta->fq_table_sql($db), "' without an explict ",
                 "'all => 1' parameter";
   }
 
@@ -1776,8 +1877,6 @@ sub update_objects
 
   $set = [ %$set ]  if(ref $set eq 'HASH');
 
-  my $meta = $object_class->meta;
-
   # Yes, I'm re-using get_objects() code like crazy, and often
   # in weird ways.  Shhhh, it's a secret.
 
@@ -2511,6 +2610,16 @@ A fully formed SQL "ORDER BY ..." clause, sans the words "ORDER BY", or a refere
 
 Within each string, any instance of "NAME." will be replaced with the appropriate "tN." table alias, where NAME is a table, foreign key, or relationship name.  All unprefixed simple column names are assumed to belong to the primary table ("t1").
 
+=item C<with_map_records [ BOOL | METHOD | HASHREF ]>
+
+When fetching related objects through a "L<many to many|Rose::DB::Object::Metadata::Relationship::ManyToMany>" relationship, objects of the L<map class|Rose::DB::Object::Metadata::Relationship::ManyToMany/map_class> are not retrieved by default.  Use this parameter to override the default behavior.
+
+If the value is "1", then each object fetched through a mapping table will have its associated map record available through a C<map_record()> attribute.
+
+If a method name is provided instead, then each object fetched through a mapping table will have its associated map record available through a method of that name.
+
+If the value is a reference to a hash, then the keys of the hash should be "many to many" relationship names, and the values should be the method names through which the maps records will be available for each relationship.
+
 =item C<with_objects OBJECTS>
 
 Also fetch sub-objects (if any) associated with rows in the primary table, where OBJECTS is a reference to an array of L<foreign key|Rose::DB::Object::Metadata/foreign_keys> or L<relationship|Rose::DB::Object::Metadata/relationships> names defined for C<object_class>.  The supported relationship types are "L<one to one|Rose::DB::Object::Metadata::Relationship::OneToOne>," "L<one to many|Rose::DB::Object::Metadata::Relationship::OneToMany>," and  "L<many to many|Rose::DB::Object::Metadata::Relationship::ManyToMany>".
